@@ -1,5 +1,7 @@
-
 /* CorAsc2.c 
+ *
+ * $Id$
+ *
  * Call me CorAsc2.  I read correlator data files from stdin and 
  * debug print more-or-less everything therein.  See also CorAsc.c. 
  * Typical usage: 
@@ -57,6 +59,9 @@
 
 #define MBUFF 100000		/* Length of buff[] */
 #define SYSCLK 32.0e6		/* Hz */
+//#define ERRMSG " ERROR: \007"
+#define ERRMSG " ERROR: "
+#define DBGMSG " DEBUG: "
 
 int t2s (double arg, char *ps);	/* Below */
 char *me;			/* My name */
@@ -84,7 +89,7 @@ int main (int argc, char *argv[])
     char flip = *byte;
  
 	int i, j, k, len, n, nt;
-	int nbuff, nlags, nap;
+	int nbuff, nlags, nap, tread, tlast;
 	double a_sin, a_cos, a_amp, a_ph, b_sin, b_cos, b_amp, b_ph;
 	char line[80];			/* Scratch */
 	T1_RecHdr *t1 = (T1_RecHdr *) buff;
@@ -111,8 +116,11 @@ int main (int argc, char *argv[])
 	struct ch_struct *pchs = t203->channels;
 	struct type_204 *t204 = (struct type_204 *) buff;
 	struct type_205 *t205 = (struct type_205 *) buff;
+	/* type_205_v0 */
+	/* type_205_v1 */
 	struct type_206_v0 *t206_0 = (struct type_206_v0 *) buff;
 	struct type_206_v1 *t206_1 = (struct type_206_v1 *) buff;
+	/* !!! type_206_v2 */
 	struct sidebands *pr_0[] = { t206_0->accepted,
 	t206_0->reason1, t206_0->reason2, t206_0->reason3, t206_0->reason4,
 	t206_0->reason5, t206_0->reason6, t206_0->reason7, t206_0->reason8
@@ -123,6 +131,7 @@ int main (int argc, char *argv[])
 	};
 	struct type_207_v0 *t207_0 = (struct type_207_v0 *) buff;
 	struct type_207_v1 *t207_1 = (struct type_207_v1 *) buff;
+	/* !!! type_207_v2 */
 	struct sbandf *psbf_0[] = {
 	t207_0->ref_pcamp, t207_0->rem_pcamp,
 	t207_0->ref_pcphase, t207_0->rem_pcphase,
@@ -148,6 +157,8 @@ int main (int argc, char *argv[])
 	struct type_208_v0 *t208 = (struct type_208_v0 *) buff;
 	struct type_208_v1 *t208_1 = (struct type_208_v1 *) buff;
 	struct type_210 *t210 = (struct type_210 *) buff;
+	/* !!! type_210_v0 */
+	/* !!! type_210_v1 */
 	struct type_212_v0 *t212 = (struct type_212_v0 *) buff;
 	struct type_212_v1 *t212_1 = (struct type_212_v1 *) buff;
 	struct type_220 *t220 = (struct type_220 *) buff;	/* ?? */
@@ -161,6 +172,7 @@ int main (int argc, char *argv[])
 	struct type_307 *t307 = (struct type_307 *) buff;
 	struct type_308 *t308 = (struct type_308 *) buff;
 	struct type_309 *t309 = (struct type_309 *) buff;
+	/* !!! type_309_v1 */
 	struct tapeDB *ttdb = (struct tapeDB *) buff;
                                     // prototypes
         short r_short_reverse (short);
@@ -171,39 +183,52 @@ int main (int argc, char *argv[])
         double r_double_reverse (double);
 
 	  /* *** Initialize *** */
+	tread = 0;
 	me = (me = strrchr (argv[0], '/')) == NULL ? argv[0] : me + 1;	/* My name */
 	for (i = 0; i < NNAMES; i++)	/* Each rname[] */
 		countt[i] = 0;			/* Initialize count */
 	  /* ** Command line OK? ** */
-	if (strlen (argv[1]) != 3)
+	if (!strcmp(argv[1], "dbg")) msglev = 0;
+	for (k = 1; k < argc; k++)
+	    if (strlen (argv[k]) != 3)
 		{
-		(void) printf ("%s Typical usage: \n", me);	/* Nope */
-		(void) printf ("    %s  xxx  <  $TMP/cortest  |  more \n", me);
-		(void) printf ("    where xxx is the record type to be printed \n");
-		(void) printf ("    (that is one of 000, 100, 101, 120, 130, etc.), \n");
-		(void) printf ("    and $TMP/cortest is an example of a correlator \n");
-		(void) printf ("    data file to be read. \n");
+		(void) fprintf (stderr,
+		    "%s Typical usage:\n"
+		    "    %s  xxx [...] <  $TMP/cortest  |  more\n"
+		    "    where xxx is the record type to be printed\n"
+		    "    (that is one of 000, 100, 101, 120, 130, etc.),\n"
+		    "    and $TMP/cortest is an example of a correlator\n"
+		    "    data file to be read.  Multiple types can be\n"
+		    "    requested, and the first one can be \"dbg\" to\n"
+		    "    turn on additional debugging or \"xxx\" to just\n"
+		    "    get the summary of record counts.\n"
+		    , me, me);
 		return (1);			/* Unsatisfactory return */
 		}
 	  /* *** Loop until break *** */
 	while (1)
 		{
 		(void) fflush (stdout);	/* Necessary? */
+		tlast = tread;
 		/* ** First read just header ** */
 		nbuff = sizeof (T1_RecHdr);
 		if ((k = fread ((void *) buff, 1, nbuff, stdin)) != nbuff)
 			{			/* Errors */
-			(void) printf ("%s:  fread() on stdin returned %d \n", me, k);
+			if (!feof(stdin)) (void) fprintf (stderr,
+			    "%s%s fread() on stdin returned %d at %dB\n",
+			    me, ERRMSG, k, tlast);
 			break;
 			}			/* Presumably end of file */
-		mbuff = k;			/* OK.  Number of bytes read (more later) */
+		mbuff = k;			/* Bytes read (more later) */
+		tread += k;
 		if (msglev < 1)		/* Debuggery? */
-			(void) fprintf (stderr, "%s DEBUG:  Read header type %.3s \n",	/* Yes */
-					me, t1->recId);
+			(void) fprintf (stderr,
+			    "%s%s Read header type %.3s at %dB\n",
+			    me, DBGMSG, t1->recId, tlast);
 		/* ** Type-000 record? ** */
 		if (strncmp (t1->recId, "000", 3) == 0)
 			{
-			/* * Yes.  Calculate the length of the additional read * */
+			/* Calculate the length of the additional read */
 			nbuff = sizeof (struct type_000) - k;
 			countt[0]++;		/* Increment record count */
 			}
@@ -242,10 +267,10 @@ int main (int argc, char *argv[])
 			else if (t120->type == SPECTRAL)	/* 5 */
 				nbuff += nlags * sizeof (struct spectral);
 			else
-				{			/* We can't handle any other type-120 types */
+				{		/* No other type-120 types */
 				(void) fprintf (stderr,
-						"%s ERROR: \007 Unknown type-120 type %d \n", me,
-						t120->type);
+				    "%s%s type-120 %d at %dB?\n",
+				    me, ERRMSG, t120->type, tlast);
 				return (-20);	/* Error */
 				}
 			countt[3]++;		/* Increment record count */
@@ -331,26 +356,30 @@ int main (int argc, char *argv[])
 		/* ** Type-206 record? ** */
 		else if (strncmp (t1->recId, "206", 3) == 0)
 			{
-			if (strncmp (t1->recVer, "00", 2) == 0)	/* Version 00? */
-				nbuff = sizeof (struct type_206_v0) - k;	/* Yes */
-			else			/* Assume version 01 */
+			if (strncmp (t1->recVer, "00", 2) == 0)
+				nbuff = sizeof (struct type_206_v0) - k;
+			else if (strncmp (t1->recVer, "01", 2) == 0)
 				nbuff = sizeof (struct type_206_v1) - k;
+			else			/* Assume version 02 */
+				nbuff = sizeof (struct type_206_v2) - k;
 			countt[17]++;		/* Increment record count */
 			}
 		/* ** Type-207 record? ** */
 		else if (strncmp (t1->recId, "207", 3) == 0)
-		{
-		if (strncmp (t1->recVer, "00", 2) == 0)	/* Version 00? */
-			nbuff = sizeof (struct type_207_v0) - k;	/* Yes */
-		else			/* Assume version 01 */
-			nbuff = sizeof (struct type_207_v1) - k;
-		countt[18]++;		/* Increment record count */
-		}
+			{
+			if (strncmp (t1->recVer, "00", 2) == 0)
+				nbuff = sizeof (struct type_207_v0) - k;
+			else if (strncmp (t1->recVer, "01", 2) == 0)
+				nbuff = sizeof (struct type_207_v1) - k;
+			else			/* Assume version 02 */
+				nbuff = sizeof (struct type_207_v2) - k;
+			countt[18]++;		/* Increment record count */
+			}
 		/* ** Type-208 record? ** */
 		else if (strncmp (t1->recId, "208", 3) == 0)
 		{
 		if (strncmp (t1->recVer, "00", 2) == 0)	/* Version 00? */
-			nbuff = sizeof (struct type_208_v0) - k;	/* Yes */
+			nbuff = sizeof (struct type_208_v0) - k;
 		else			/* Assume version 01 */
 			nbuff = sizeof (struct type_208_v1) - k;
 		countt[19]++;		/* Increment record count */
@@ -389,8 +418,9 @@ int main (int argc, char *argv[])
 			{
 			/* Special case variable-length record */
 			if (msglev < 1)		/* Debuggery? */
-				(void) fprintf (stderr, "%s DEBUG:  ps_length = %d \n",
-						me, flip_int(t221->ps_length));
+				(void) fprintf (stderr,
+				    "%s%s ps_length = %d at %dB\n",
+				    me,DBGMSG,flip_int(t221->ps_length),tlast);
 			nbuff = sizeof (struct type_221) - sizeof (char) + flip_int(t221->ps_length) - k;
 			if (flip_short(t221->padded) && nbuff % 8 > 0)	/* Pad to 8 bytes? */
 				nbuff += 8 - nbuff % 8;	/* Yes */
@@ -458,29 +488,33 @@ int main (int argc, char *argv[])
 		else
 			{			/* Unknown recId */
 			(void) fprintf (stderr,
-					"%s ERROR: \007 Unknown record type \"%.3s\" \n", me,
-					t1->recId);
+				"%s%s Unknown record type \"%.3s\" at %dB\n",
+				me, ERRMSG, t1->recId, tlast);
 			return (-21);		/* Error */
 			}
 		/* ** Check:  Is buff[] big enough? ** */
 		if (mbuff + nbuff > MBUFF)
 			{			/* Would buffer overflow? */
-			(void) fprintf (stderr,	/* Yes */
-					"%s ERROR:  Buffer overflow record type %.3s  mbuff+nbuff = %d \n",
-					me, t1->recId, mbuff + nbuff);
+			(void) fprintf (stderr,
+				"%s%s Buffer overflow record type"
+				" %.3s  mbuff+nbuff = %d at %dB\n",
+				me, ERRMSG, t1->recId, mbuff + nbuff, tlast);
 			return (-22);		/* Fatal error */
 			}
 		/* ** Read that much more data ** */
 		if ((k = fread ((void *) (buff + mbuff), 1, nbuff, stdin)) != nbuff)
 			{
-			(void) fprintf (stderr, "%s:  fread() on stdin returned %d \n", me,
-					k);
+			(void) fprintf (stderr,
+				"%s%s fread() on stdin returned %d at %dB\n",
+				me, ERRMSG, k, tlast);
 			break;
 			}			/* Presumably end of file */
 		mbuff += k;			/* OK.  Total number of bytes read */
+		tread += k;
 		if (msglev < 1)		/* Debuggery? */
-			(void) fprintf (stderr, "%s DEBUG:  Read record type %.3s \n",	/* Yes */
-				me, t1->recId);
+			(void) fprintf (stderr,
+				"%s%s Read record type %.3s at %dB\n",	
+				me, DBGMSG, t1->recId, tlast);
 		/* *** Here we have a complete record; should we print it? *** */
 		for (i = 1; i < argc; i++)	/* Each command-line argument */
 			if (strncasecmp (argv[i], t1->recId, 3) == 0)	/* Print this one? */
@@ -1503,8 +1537,9 @@ int t2s (			/* Convert a time to a printable string */
 		{				/* Range OK? */
 		/* (That's the maximum number of seconds in a year) */
 		if (msglev < 1)		/* Nope.  Debuggery? */
-			(void) fprintf (stderr, "%s t2s() ERROR: \007 %.3e seconds is illegal \n",
-				me, arg);
+			(void) fprintf (stderr,
+				"%s%s t2s() %.3e seconds is illegal\n",
+				me, ERRMSG, arg);
 		(void) strcpy (ps, " ERROR! ");
 		return (-1);		/* Error */
 		}
@@ -1633,3 +1668,7 @@ double r_double_reverse (double j)
 		
 	return j;
     }
+
+/*
+ * eof
+ */
