@@ -9,26 +9,17 @@
 /* Overhauled and beautified by CJL April 29, 1992                      */
 /* Modified for two-bit operation.                   rjc 93.3.22        */
 /* Change scale factor from 30000 to 10000.          rjc 94.1.24        */
+/* Overhauled                                        cjl 99.4.27        */
 /* Mult. scale by 4/3 since Mk4 has valid 0 rotator  rjc 99.8.3         */
 /* Apply different normalization for 2 bit case      rjc 01.01.19       */
 /* Break out normalization code into separate func.  rjc 01.11.7        */
-/*                                                                      */
-/************************************************************************/
-
-/************************************************************************/
-/*                                                                      */
-/* Substantial rewrite needed for Mk4, including support for variable   */
-/* number of lags, multiple polarizations.                              */
+/* apply delay offset by channel if non-zero         rjc 2011.8.10      */
 /*                                                                      */
 /*      Inputs:     pass        Contains various essential parameters   */
 /*                  pol         0,1,2,3 = LL,RR,LR,RL                   */
 /*                  fr          fourfit frequency channel number        */
 /*                  ap          Sequential AP number                    */
 /*                                                                      */
-/*      Output:     t_pcal      Does this belong here?                  */
-/*                                                                      */
-/* Overhauled 27 April 1999 by CJL                                      */
-/*                                                                      */
 /************************************************************************/
 #include <stdio.h>
 #include <math.h>
@@ -57,7 +48,9 @@ int pol, fr, ap;
     unsigned short bitshift;
     double theta, shift, dd, norm_const, fb_fact, fb_amp_ratio();
     double samp_per_ap, corrfact, rawcorr, factor, mean;
-    int flagmask;
+    double diff_delay, deltaf;
+    int flagmask,
+        freq_no;
     extern struct type_param param;
     extern struct type_status status;
 
@@ -189,9 +182,9 @@ int pol, fr, ap;
                     status.sliver_errors++;
                     msg ("marking ap %d for a sliver error", 0, ap);
                                         /* mark this sideband & pol piece of this AP bad */
-                datum->flag &= ~(1 << (2 * pol + sb));
-                break;                  /* break out of loop over lags  */
-                }
+                    datum->flag &= ~(1 << (2 * pol + sb));
+                    break;              /* break out of loop over lags  */
+                    }
                                         /* Convert lag values to true correlation
                                          * coefficients. Factor of 8 is due to hidden
                                          * 3 lower order bits in accumulator */
@@ -237,7 +230,7 @@ int pol, fr, ap;
                 {
                 msg ("skipping data for ap %d pol %d sb %d", -2, ap, pol, sb);
                 continue;                   /* skip over rest of the sideband loop */
-            }
+                }
                                         /* Increment a.p. counts */
                                         /* Integer counts ... */
             (status.ap_num[sb][fr])++;
@@ -258,7 +251,7 @@ int pol, fr, ap;
                                         /* FFT to X-power spectrum  */
             FFT1 (xcor, nlags*2, 1, xp_spec, 1);
 
-                                        /* apply spectral filter, if specified */
+                                        /* apply spectral filter as needed */
             apply_passband (sb, fdata, xp_spec, nlags*2);
 
                                         /* Adjust for Bit-shift */
@@ -346,6 +339,10 @@ int pol, fr, ap;
                 xp_spec[i].im = rawdatum->ld.spec[i].im;
                 }
             }
+
+                                        /* apply spectral filter as needed */
+            apply_passband (sb, fdata, xp_spec, nlags*2);
+
                                         /* Put sidebands together.  For each sb, */
                                         /* the Xpower array, which is the FFT across */
                                         /* lags, is symmetrical about DC of the */
@@ -392,6 +389,31 @@ int pol, fr, ap;
     msg ("usbfrac %1f lsbfrac %1f factor %1f", -2, datum->usbfrac, datum->lsbfrac, factor);
     for (i=0; i<4*nlags; i++) S[i] = s_mult (S[i], factor);
 
+#ifdef NORM_HACK_HOOK
+#warning "spectral hacking enabled -- see hook_norm.c"
+    NORM_HACK_HOOK;
+#endif /* NORM_HACK_HOOK */
+
+                                        // apply delay offset phase ramp
+                                        // iff the offset is non-zero
+    freq_no = fcode(pass->pass_data[fr].freq_code);
+    diff_delay = pass->control.delay_offs[freq_no].rem - pass->control.delay_offs[freq_no].ref;
+    if (diff_delay)
+        {
+        for (i=1, j=4*nlags-1; i<nlags; i++, j--)
+            {
+                                        // calculate offset frequency of DC edge in
+                                        // GHz from the reference frequency for USB
+            deltaf = 1e-3 * (fdata->frequency - param.ref_freq 
+                           + i / (2e6 * param.samp_period * nlags));
+                                        // apply phase ramp to spectral points 
+            S[i] = c_mult (S[i], c_exp (2.0 * M_PI * diff_delay * deltaf));
+                                        // ditto for LSB
+            deltaf = 1e-3 * (fdata->frequency - param.ref_freq 
+                           - i / (2e6 * param.samp_period * nlags));
+            S[j] = c_mult (S[j], c_exp (2.0 * M_PI * diff_delay * deltaf));
+            }
+        }
                                         /* Collect the results */
     if(datum->flag != 0)
         {
