@@ -84,6 +84,9 @@ struct c_block *cb_ptr;
 
         cb_ptr -> gates[i].on_delay = NULLINT;
         cb_ptr -> gates[i].duration = NULLINT;
+
+        cb_ptr -> delay_offs[i].ref = NULLFLOAT;
+        cb_ptr -> delay_offs[i].rem = NULLFLOAT;
 	}
 
     for (i=0; i<2*MAX_CHAN_PP; i++)
