@@ -380,6 +380,36 @@ int parser ()
                        cb_ptr -> passband[nv] = float_values[tval];
                        }
 
+                   else if (toknum == DELAY_OFFS_) // is this a channel delay offset?
+                       {
+                       i = fcode(parsed_codes[nv]);
+                       if (i<0 || i>MAX_CHAN_PP-1)
+                           {
+                           msg ("Invalid delay offset frequency code",2);
+                           return (-1);
+                           }
+                                         /* get phases from appropriate place */
+                       if (tokens[ntok].category == INTEGER)
+                           fval = tval;
+                       else
+                           fval = float_values[tval];
+
+                                                   /* delays normally get stored
+                                                      for only one station, and
+                                                      into correct freq slot.
+                                                      If both specified, set remote
+                                                      delay offset to value, and zero
+                                                      out the reference value. */
+                       if (cb_ptr -> baseline[1] == WILDCARD)
+                           cb_ptr -> delay_offs[i].ref = fval;
+                       else if (cb_ptr -> baseline[0] == WILDCARD)
+                           cb_ptr -> delay_offs[i].rem = fval;
+                       else 
+                           {
+                           cb_ptr -> delay_offs[i].ref = 0.0;
+                           cb_ptr -> delay_offs[i].rem = fval;
+                           }
+                       }
                nv++;                       /* bump index for next vector parm */
                break;
 
