@@ -202,8 +202,9 @@ struct type_pass *pass;
                     if (k<MAX_PCF && (mask & 1) == 0)
                         {
                         pass->pcinband[stn][fr][nin] = k;
-                        msg ("pcinband[%d][%d][%d] %d", 
-                              0,stn, fr, nin, pass->pcinband[stn][fr][nin]);
+                        msg ("adding pcinband[%d][%d][%d] %d pcfreq_hz %lf sb %c", 
+                              0,stn, fr, nin, pass->pcinband[stn][fr][nin], 
+                              pcfreq_hz, ovex->st[n].channels[0].net_sideband);
                         nin++;
                         }
                                     // move on to next tone in the band
